Tutorials
=========

The following tutorials will help you get acquainted with Asphalt application development.
It is expected that the reader have at least basic understanding of the Python language.

Code for all tutorials can be found in the ``examples`` directory in the source distribution or in
the
`Github repository <https://github.com/asphalt-framework/asphalt/tree/master/examples>`_.

.. toctree::
   :maxdepth: 2

   echo
   webnotifier
